Genuine AI functions used in iMICS Lab research Projects.
For more information, please refer to our website at imics.ca

\@author: Ernest (Khashayar) Namdar ernest.namdar\@utoronto.ca

AUCPlus is an augmented AUC function
It returns conventional AUC, our augmented AUC, and multiple parameters such as sensitivity and specificity at each threshold
